package dev.adriankuta.pixabay

import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.navigation.NavHostController
import androidx.navigation.NavType
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import androidx.navigation.navArgument
import dev.adriankuta.pixabay.PixabayDestinations.PHOTO_DETAILS_ROUTE
import dev.adriankuta.pixabay.PixabayDestinations.SEARCH_ROUTE
import dev.adriankuta.pixabay.PixabayDestinationsArgs.PHOTO_ID_ARG
import dev.adriankuta.pixabay.feature.details.PhotoDetailRoute
import dev.adriankuta.pixabay.feature.search.SearchRoute

@Composable
fun PixabayNavGraph(
    modifier: Modifier = Modifier,
    navController: NavHostController = rememberNavController(),
    startDestination: String = SEARCH_ROUTE,
    navActions: PixabayNavigationActions = remember(navController) {
        PixabayNavigationActions(navController)
    }
) {
    NavHost(
        navController = navController,
        startDestination = startDestination,
        modifier = modifier
    ) {
        composable(SEARCH_ROUTE) {
            SearchRoute(
                onGoToItem = { photoId -> navActions.navigateToDetails(photoId) },
            )
        }

        composable(
            PHOTO_DETAILS_ROUTE,
            arguments = listOf(
                navArgument(PHOTO_ID_ARG) { type = NavType.IntType }
            )
        ) { entry ->
            PhotoDetailRoute(
                photoId = entry.arguments?.getInt(PHOTO_ID_ARG)!!,
                onBack = { navController.popBackStack() },
            )
        }
    }
}